@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 import functools
 import re
@@ -22,10 +20,10 @@ from typing import Dict, Sequence, Tuple, Type, Union
 import pkg_resources
 
 import google.api_core.client_options as ClientOptions  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
 from google.cloud.binaryauthorization_v1beta1.services.binauthz_management_service_v1_beta1 import (
@@ -33,8 +31,7 @@ from google.cloud.binaryauthorization_v1beta1.services.binauthz_management_servi
 )
 from google.cloud.binaryauthorization_v1beta1.types import resources
 from google.cloud.binaryauthorization_v1beta1.types import service
-from google.protobuf import timestamp_pb2 as timestamp  # type: ignore
-
+from google.protobuf import timestamp_pb2  # type: ignore
 from .transports.base import (
     BinauthzManagementServiceV1Beta1Transport,
     DEFAULT_CLIENT_INFO,
@@ -68,35 +65,30 @@ class BinauthzManagementServiceV1Beta1AsyncClient:
     parse_policy_path = staticmethod(
         BinauthzManagementServiceV1Beta1Client.parse_policy_path
     )
-
     common_billing_account_path = staticmethod(
         BinauthzManagementServiceV1Beta1Client.common_billing_account_path
     )
     parse_common_billing_account_path = staticmethod(
         BinauthzManagementServiceV1Beta1Client.parse_common_billing_account_path
     )
-
     common_folder_path = staticmethod(
         BinauthzManagementServiceV1Beta1Client.common_folder_path
     )
     parse_common_folder_path = staticmethod(
         BinauthzManagementServiceV1Beta1Client.parse_common_folder_path
     )
-
     common_organization_path = staticmethod(
         BinauthzManagementServiceV1Beta1Client.common_organization_path
     )
     parse_common_organization_path = staticmethod(
         BinauthzManagementServiceV1Beta1Client.parse_common_organization_path
     )
-
     common_project_path = staticmethod(
         BinauthzManagementServiceV1Beta1Client.common_project_path
     )
     parse_common_project_path = staticmethod(
         BinauthzManagementServiceV1Beta1Client.parse_common_project_path
     )
-
     common_location_path = staticmethod(
         BinauthzManagementServiceV1Beta1Client.common_location_path
     )
@@ -104,17 +96,42 @@ class BinauthzManagementServiceV1Beta1AsyncClient:
         BinauthzManagementServiceV1Beta1Client.parse_common_location_path
     )
 
-    from_service_account_info = (
-        BinauthzManagementServiceV1Beta1Client.from_service_account_info
-    )
-    from_service_account_file = (
-        BinauthzManagementServiceV1Beta1Client.from_service_account_file
-    )
+    @classmethod
+    def from_service_account_info(cls, info: dict, *args, **kwargs):
+        """Creates an instance of this client using the provided credentials
+            info.
+
+        Args:
+            info (dict): The service account private key info.
+            args: Additional arguments to pass to the constructor.
+            kwargs: Additional arguments to pass to the constructor.
+
+        Returns:
+            BinauthzManagementServiceV1Beta1AsyncClient: The constructed client.
+        """
+        return BinauthzManagementServiceV1Beta1Client.from_service_account_info.__func__(BinauthzManagementServiceV1Beta1AsyncClient, info, *args, **kwargs)  # type: ignore
+
+    @classmethod
+    def from_service_account_file(cls, filename: str, *args, **kwargs):
+        """Creates an instance of this client using the provided credentials
+            file.
+
+        Args:
+            filename (str): The path to the service account private key json
+                file.
+            args: Additional arguments to pass to the constructor.
+            kwargs: Additional arguments to pass to the constructor.
+
+        Returns:
+            BinauthzManagementServiceV1Beta1AsyncClient: The constructed client.
+        """
+        return BinauthzManagementServiceV1Beta1Client.from_service_account_file.__func__(BinauthzManagementServiceV1Beta1AsyncClient, filename, *args, **kwargs)  # type: ignore
+
     from_service_account_json = from_service_account_file
 
     @property
     def transport(self) -> BinauthzManagementServiceV1Beta1Transport:
-        """Return the transport used by the client instance.
+        """Returns the transport used by the client instance.
 
         Returns:
             BinauthzManagementServiceV1Beta1Transport: The transport used by the client instance.
@@ -129,14 +146,14 @@ class BinauthzManagementServiceV1Beta1AsyncClient:
     def __init__(
         self,
         *,
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         transport: Union[
             str, BinauthzManagementServiceV1Beta1Transport
         ] = "grpc_asyncio",
         client_options: ClientOptions = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
-        """Instantiate the binauthz management service v1 beta1 client.
+        """Instantiates the binauthz management service v1 beta1 client.
 
         Args:
             credentials (Optional[google.auth.credentials.Credentials]): The
@@ -168,7 +185,6 @@ class BinauthzManagementServiceV1Beta1AsyncClient:
             google.auth.exceptions.MutualTlsChannelError: If mutual TLS transport
                 creation failed for any reason.
         """
-
         self._client = BinauthzManagementServiceV1Beta1Client(
             credentials=credentials,
             transport=transport,
@@ -211,7 +227,6 @@ class BinauthzManagementServiceV1Beta1AsyncClient:
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -220,9 +235,8 @@ class BinauthzManagementServiceV1Beta1AsyncClient:
 
         Returns:
             google.cloud.binaryauthorization_v1beta1.types.Policy:
-                A
-                [policy][google.cloud.binaryauthorization.v1beta1.Policy]
-                for container image binary authorization.
+                A [policy][google.cloud.binaryauthorization.v1beta1.Policy] for container
+                   image binary authorization.
 
         """
         # Create or coerce a protobuf request object.
@@ -239,7 +253,6 @@ class BinauthzManagementServiceV1Beta1AsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if name is not None:
             request.name = name
 
@@ -252,8 +265,10 @@ class BinauthzManagementServiceV1Beta1AsyncClient:
                 maximum=60.0,
                 multiplier=1.3,
                 predicate=retries.if_exception_type(
-                    exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
+                    core_exceptions.DeadlineExceeded,
+                    core_exceptions.ServiceUnavailable,
                 ),
+                deadline=600.0,
             ),
             default_timeout=600.0,
             client_info=DEFAULT_CLIENT_INFO,
@@ -304,7 +319,6 @@ class BinauthzManagementServiceV1Beta1AsyncClient:
                 This corresponds to the ``policy`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -313,9 +327,8 @@ class BinauthzManagementServiceV1Beta1AsyncClient:
 
         Returns:
             google.cloud.binaryauthorization_v1beta1.types.Policy:
-                A
-                [policy][google.cloud.binaryauthorization.v1beta1.Policy]
-                for container image binary authorization.
+                A [policy][google.cloud.binaryauthorization.v1beta1.Policy] for container
+                   image binary authorization.
 
         """
         # Create or coerce a protobuf request object.
@@ -332,7 +345,6 @@ class BinauthzManagementServiceV1Beta1AsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if policy is not None:
             request.policy = policy
 
@@ -345,8 +357,10 @@ class BinauthzManagementServiceV1Beta1AsyncClient:
                 maximum=60.0,
                 multiplier=1.3,
                 predicate=retries.if_exception_type(
-                    exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
+                    core_exceptions.DeadlineExceeded,
+                    core_exceptions.ServiceUnavailable,
                 ),
+                deadline=600.0,
             ),
             default_timeout=600.0,
             client_info=DEFAULT_CLIENT_INFO,
@@ -417,7 +431,6 @@ class BinauthzManagementServiceV1Beta1AsyncClient:
                 This corresponds to the ``attestor`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -426,9 +439,9 @@ class BinauthzManagementServiceV1Beta1AsyncClient:
 
         Returns:
             google.cloud.binaryauthorization_v1beta1.types.Attestor:
-                An [attestor][google.cloud.binaryauthorization.v1beta1.Attestor] that attests to container image
-                   artifacts. An existing attestor cannot be modified
-                   except where indicated.
+                An [attestor][google.cloud.binaryauthorization.v1beta1.Attestor] that attests
+                   to container image artifacts. An existing attestor
+                   cannot be modified except where indicated.
 
         """
         # Create or coerce a protobuf request object.
@@ -445,7 +458,6 @@ class BinauthzManagementServiceV1Beta1AsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if parent is not None:
             request.parent = parent
         if attestor_id is not None:
@@ -500,7 +512,6 @@ class BinauthzManagementServiceV1Beta1AsyncClient:
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -509,9 +520,9 @@ class BinauthzManagementServiceV1Beta1AsyncClient:
 
         Returns:
             google.cloud.binaryauthorization_v1beta1.types.Attestor:
-                An [attestor][google.cloud.binaryauthorization.v1beta1.Attestor] that attests to container image
-                   artifacts. An existing attestor cannot be modified
-                   except where indicated.
+                An [attestor][google.cloud.binaryauthorization.v1beta1.Attestor] that attests
+                   to container image artifacts. An existing attestor
+                   cannot be modified except where indicated.
 
         """
         # Create or coerce a protobuf request object.
@@ -528,7 +539,6 @@ class BinauthzManagementServiceV1Beta1AsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if name is not None:
             request.name = name
 
@@ -541,8 +551,10 @@ class BinauthzManagementServiceV1Beta1AsyncClient:
                 maximum=60.0,
                 multiplier=1.3,
                 predicate=retries.if_exception_type(
-                    exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
+                    core_exceptions.DeadlineExceeded,
+                    core_exceptions.ServiceUnavailable,
                 ),
+                deadline=600.0,
             ),
             default_timeout=600.0,
             client_info=DEFAULT_CLIENT_INFO,
@@ -590,7 +602,6 @@ class BinauthzManagementServiceV1Beta1AsyncClient:
                 This corresponds to the ``attestor`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -599,9 +610,9 @@ class BinauthzManagementServiceV1Beta1AsyncClient:
 
         Returns:
             google.cloud.binaryauthorization_v1beta1.types.Attestor:
-                An [attestor][google.cloud.binaryauthorization.v1beta1.Attestor] that attests to container image
-                   artifacts. An existing attestor cannot be modified
-                   except where indicated.
+                An [attestor][google.cloud.binaryauthorization.v1beta1.Attestor] that attests
+                   to container image artifacts. An existing attestor
+                   cannot be modified except where indicated.
 
         """
         # Create or coerce a protobuf request object.
@@ -618,7 +629,6 @@ class BinauthzManagementServiceV1Beta1AsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if attestor is not None:
             request.attestor = attestor
 
@@ -631,8 +641,10 @@ class BinauthzManagementServiceV1Beta1AsyncClient:
                 maximum=60.0,
                 multiplier=1.3,
                 predicate=retries.if_exception_type(
-                    exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
+                    core_exceptions.DeadlineExceeded,
+                    core_exceptions.ServiceUnavailable,
                 ),
+                deadline=600.0,
             ),
             default_timeout=600.0,
             client_info=DEFAULT_CLIENT_INFO,
@@ -678,7 +690,6 @@ class BinauthzManagementServiceV1Beta1AsyncClient:
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -708,7 +719,6 @@ class BinauthzManagementServiceV1Beta1AsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if parent is not None:
             request.parent = parent
 
@@ -721,8 +731,10 @@ class BinauthzManagementServiceV1Beta1AsyncClient:
                 maximum=60.0,
                 multiplier=1.3,
                 predicate=retries.if_exception_type(
-                    exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
+                    core_exceptions.DeadlineExceeded,
+                    core_exceptions.ServiceUnavailable,
                 ),
+                deadline=600.0,
             ),
             default_timeout=600.0,
             client_info=DEFAULT_CLIENT_INFO,
@@ -773,7 +785,6 @@ class BinauthzManagementServiceV1Beta1AsyncClient:
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -794,7 +805,6 @@ class BinauthzManagementServiceV1Beta1AsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if name is not None:
             request.name = name
 
@@ -807,8 +817,10 @@ class BinauthzManagementServiceV1Beta1AsyncClient:
                 maximum=60.0,
                 multiplier=1.3,
                 predicate=retries.if_exception_type(
-                    exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
+                    core_exceptions.DeadlineExceeded,
+                    core_exceptions.ServiceUnavailable,
                 ),
+                deadline=600.0,
             ),
             default_timeout=600.0,
             client_info=DEFAULT_CLIENT_INFO,
